|PyPI Version| |Build Status| |Coverage Status| |Python Version|

Spoonbill converts data that conforms to the `Open Contracting Data Standard (OCDS) <https://standard.open-contracting.org/latest/en/>`__ from JSON to Excel / CSV ("tables", hereafter). This is also known as "flattening" a JSON file.

If you are viewing this on GitHub or PyPI, open the `full documentation <https://open-contracting.github.io/spoonbill/>`__ for additional details.

.. |PyPI Version| image:: https://img.shields.io/pypi/v/spoonbill.svg
   :target: https://pypi.org/project/spoonbill/
.. |Build Status| image:: https://github.com/open-contracting/spoonbill/workflows/CI/badge.svg
   :target: https://github.com/open-contracting/spoonbill/actions?query=workflow%3ACI
.. |Coverage Status| image:: https://coveralls.io/repos/github/open-contracting/spoonbill/badge.svg?branch=main
   :target: https://coveralls.io/github/open-contracting/spoonbill?branch=main
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/spoonbill.svg
   :target: https://pypi.org/project/spoonbill/
